# rcplus-alloy-lib-py-common

![PyPI](https://img.shields.io/pypi/v/rcplus-alloy-common)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rcplus-alloy-common)
![Coverage badge](./coverage.svg)

Current version: **v7.9.2**

---

Python utilities for RC+/Alloy.

_**NOTE**_: This Python package is published to PyPI.org as publicly available package.

## Install

```bash
pip install -U rcplus-alloy-common
```

## Usage

### Structured logging

TODO

### Application metrics

TODO

### Airflow

```bash
pip install -U rcplus-alloy-common[airflow]
```

TODO

### AWS

```bash
pip install -U rcplus-alloy-common[aws]
```

TODO

### GAM
> [!NOTE]
> GAM contains only data models definitions now

```bash
pip install -U rcplus-alloy-common[gam]
```
